4.25. umbra.exceptions — Umbra 1.0.9 documentation

# 4.25. umbra.exceptions

exceptions.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines Umbra package exceptions.

Others:

## 4.25.1. Functions

`umbra.exceptions.` `notifyExceptionHandler`(*args)

  Provides a notifier exception handler.

  Parameters: | *args (*) – Arguments.
  Returns: | Definition success.
  Return type: | bool

## 4.25.2. Classes

class `umbra.exceptions.` `AbstractEngineError`(value)

  Bases: `foundations.exceptions.AbstractError`

  Defines the abstract base class for engine related exceptions.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `EngineConfigurationError`(value)

  Bases: `umbra.exceptions.AbstractEngineError`

  Defines engine configuration exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `EngineInitializationError`(value)

  Bases: `umbra.exceptions.AbstractEngineError`

  Defines engine initialization exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `ResourceExistsError`(value)

  Bases: `foundations.exceptions.AbstractOsError`

  Defines non existing resource exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `AbstractActionsManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  Defines the abstract base class for `umbra.managers.actionsManager.ActionsManager` related exceptions.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `CategoryExistsError`(value)

  Bases: `umbra.exceptions.AbstractActionsManagerError`

  Defines non existing category exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `ActionExistsError`(value)

  Bases: `umbra.exceptions.AbstractActionsManagerError`

  Defines non existing action exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `AbstractPatchesManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  Defines the abstract base class for `umbra.managers.patchesManager.PatchesManager` related exceptions.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `PatchRegistrationError`(value)

  Bases: `umbra.exceptions.AbstractPatchesManagerError`

  Defines patch registration exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `PatchInterfaceError`(value)

  Bases: `umbra.exceptions.AbstractPatchesManagerError`

  Defines patch interface exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `PatchApplyError`(value)

  Bases: `umbra.exceptions.AbstractPatchesManagerError`

  Defines patch apply exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `AbstractLayoutsManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  Defines the abstract base class for `umbra.managers.layoutsManager.LayoutsManager` related exceptions.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `LayoutRegistrationError`(value)

  Bases: `umbra.exceptions.AbstractLayoutsManagerError`

  Defines layout registration exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `LayoutExistError`(value)

  Bases: `umbra.exceptions.AbstractLayoutsManagerError`

  Defines non existing layout exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `AbstractFileSystemEventsManagerError`(value)

  Bases: `foundations.exceptions.AbstractError`

  Defines the abstract base class for `umbra.managers.fileSystemEventsManager.FileSystemEventsManager` related exceptions.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `PathRegistrationError`(value)

  Bases: `umbra.exceptions.AbstractFileSystemEventsManagerError`

  Defines path registration exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `PathExistsError`(value)

  Bases: `umbra.exceptions.AbstractFileSystemEventsManagerError`

  Defines non existing path exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `AbstractLanguageError`(value)

  Bases: `foundations.exceptions.AbstractError`

  Defines the abstract base class for language related exceptions.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.

class `umbra.exceptions.` `LanguageGrammarError`(value)

  Bases: `umbra.exceptions.AbstractLanguageError`

  Defines language grammar exception.

  Initializes the class.

  Parameters: | value (unicode) – Error value or message.